<?php
/*
Plugin Name: AMP Custom Post Type
Description: Enable Custom post type support for AMP pages
Author: Ahmed Kaludi, Mohammed Kaludi
Version: 1.6
Author URI: https://ampforwp.com/
*/
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! defined( 'AMP_CPT_VERSION' ) ) {
    define( 'AMP_CPT_VERSION', '1.6' );
}
// this is the URL our updater / license checker pings. This should be the URL of the site with EDD installed
define( 'AMP_CPT_STORE_URL', 'https://accounts.ampforwp.com/' ); // you should use your own CONSTANT name, and be sure to replace it throughout this file

// the name of your product. This should match the download name in EDD exactly
define( 'AMP_CPT_ITEM_NAME', 'Custom Post Type Support for AMP' );

// the download ID. This is the ID of your product in EDD and should match the download ID visible in your Downloads list (see example below)
//define( 'AMPFORWP_ITEM_ID', 2502 );
// the name of the settings page for the license input to be displayed
define( 'AMP_CPT_LICENSE_PAGE', 'custom-post-type-support-for-amp' );
if(! defined('AMP_CPT_ITEM_FOLDER_NAME')){
    $folderName = basename(__DIR__);
    define( 'AMP_CPT_ITEM_FOLDER_NAME', $folderName );
}

//custom prefix for Fuctions and variables : ampforwp_cpt_

// Plugin activation check
if(is_admin()){
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		if ( !class_exists('Ampforwp_Init') ) {
			add_filter( 'plugin_action_links', 'ampforwp_cpt_plugin_activation_link_new', 10, 6 );
			// Add Activate Parent Plugin button in settings page

				function ampforwp_cpt_plugin_activation_link_new( $actions, $plugin_file ) {
					static $plugin;
					if (!isset($plugin))
						$plugin = plugin_basename(__FILE__);
						if ($plugin == $plugin_file) {
								$cpt_settings_button = array('settings' => '<a href="admin.php?page=amp_options&tab=2">' . __('Settings', 'ampforwp_cpt') . '</a>');
							if ( class_exists('Ampforwp_Init') ) {
							    //if parent plugin is activated
										$actions = array_merge( $actions, $cpt_settings_button );
							} else{
								if(class_exists('Ampforwp_Init')){
									$actions = array_merge( $actions, $cpt_settings_button );
								}else{
								$please_activate_parent_plugin = array('Please Activate Parent plugin' => '<a href="plugin-install.php?s=accelerated+mobile+pages&tab=search&type=term">'. __('Please Activate Parent plugin', 'ampforwp') . '</a>');
								$actions = array_merge( $please_activate_parent_plugin,$actions );
							}
							}
		 				}
						return $actions;
			}
		}
	}

//Options for Custom Post Types Starts here
if ( ! function_exists( 'ampforwp_cpt_custom_post_type_support_section' ) ) {
	function ampforwp_cpt_custom_post_type_support_section($sections){

		$options=get_option('ampforwp_cpt_generated_post_types');

	    $sections[] = array(
	        'title' 	=> __('Custom Post Type', 'redux-framework-demo'),
	        'icon' 		=> 'el el-th-large',
			'id'       => 'ampforwp-cpt-subsection',
	        'fields' 	=>  array(
				array(
					'id'       => 'ampforwp-custom-type',
					'type'     => 'select',
					'title'    => __('Number of Custom Types', 'redux-framework-demo'),
					'multi'=> true,
					//'data' => 'post_type',
					'options'=>$options,
				),
				array(
					'id'       => 'ampforwp-custom-type-amp-endpoint',
					'type'     => 'switch',
					'title'    => __('Make endpoint ?amp', 'redux-framework-demo'),
					'default'   => 0,
					'subtitle'  => 'Enable this option when /amp/ is giving 404 after resaving the permalink settings.',
					'desc'      => __( 'Making endpoints ?amp is required for directory based themes or have multiple taxonomies in the url. Question mark in the url will not make any differance in the SEO.' ),

				),
			),
	    );
	    return $sections;
	}
}
// Get all the post types and add metaboxs of the ads in this post types
add_action('admin_init', 'ampforwp_cpt_generate_postype');
function ampforwp_cpt_generate_postype(){
 ampforwp_cpt_post_types();
}

function ampforwp_cpt_post_types(){
  $args       = "";
  $get_post_types = "";
  $post_types   = array();

  $args = array(
     'public'   => true,
  );

  $get_post_types = get_post_types( $args, 'objects');

  foreach ( $get_post_types  as $post_type ) {
    $post_types[$post_type->name] = $post_type->label;
  }

  $post_types =apply_filters( 'ampforwp_cpt_modify_post_types', $post_types );


	if ( isset($post_types['post'] ) ) { unset($post_types['post']); } 
	if ( isset($post_types['page'] ) )  { unset($post_types['page']); }
	if ( isset($post_types['attachment'] ) ) {unset($post_types['attachment']);}
	if ( isset($post_types['guest-author'] ) ) {unset($post_types['guest-author']);}
	if ( isset($post_types['amp-cta'] ) ) {unset($post_types['amp-cta']);}
    if ( isset($post_types['wprss_feed_item'] ) ){unset($post_types['wprss_feed_item']);}
	if ( isset($post_types['wprss_feed'] ) ) {unset($post_types['wprss_feed']);}

  $options=get_option('ampforwp_cpt_generated_post_types');

    $count_current_pt=count( $post_types );
    $count_saved_pt = count( $options);

    if($count_current_pt>$count_saved_pt){
      $array_1 = (array) $post_types;
	  $array_2 = (array) $options;
    }

    else{
      $array_1 = (array) $options;
	  $array_2 = (array) $post_types;
    }

	if( array_diff( $array_1, $array_2 ) ) {
      update_option('ampforwp_cpt_generated_post_types',$post_types);
    }
}
add_filter("redux/options/redux_builder_amp/sections", 'ampforwp_cpt_custom_post_type_support_section');

//Adding Custom Post type starts here
if ( ! function_exists( 'ampforwp_cpt_add_custom_post_type_support' ) ) {
	function ampforwp_cpt_add_custom_post_type_support() {
		//add_rewrite_endpoint( AMP_QUERY_VAR, EP_PERMALINK | EP_PAGES | EP_ROOT );

		global $redux_builder_amp;
		if($redux_builder_amp['ampforwp-custom-type']){
			foreach($redux_builder_amp['ampforwp-custom-type'] as $custom_post){
			    add_post_type_support( $custom_post, AMP_QUERY_VAR );
			}
		}

	}
	add_action( 'init', 'ampforwp_cpt_add_custom_post_type_support', 100);
}

add_filter('ampforwp_modify_rel_canonical','ampforwp_cpt_modify_rel_canonical');

function ampforwp_cpt_modify_rel_canonical($url) {

	global $redux_builder_amp, $wp;
	$post_types = "";
	$current_cpt_url = "";
	$post_types = $redux_builder_amp['ampforwp-custom-type'];

	// If Option "Make endpoint ?amp" is Off then return.
	if ( ! $redux_builder_amp['ampforwp-custom-type-amp-endpoint'] ) {
		return $url;
	}

	if ( is_post_type_archive( $post_types ) ||  is_singular( $post_types )) {
		$current_cpt_url = home_url( $wp->request );
		$url 			= trailingslashit( $current_cpt_url ) . '?amp';

		return $url;
	}
	return $url;
}

// Pods Framework Compatibility
 function ampforwp_cpt_the_content(){
		$filter = 'the_content';

		// get the current post type
		$current_post_type =  ampforwp_cpt_current_post_type();

		//now use other methods in class to build array to search in/ use
		$possible_pods = ampforwp_current_auto_pods();
    
		//check if $current_post_type is the key of the array of possible pods
		if ( isset( $possible_pods[ $current_post_type ] ) ) {

			$this_pod = $possible_pods[ $current_post_type ];

			if ( is_singular( $current_post_type ) ) {
				$filter =  $this_pod[ 'single_filter' ];
			} elseif ( is_post_type_archive( $current_post_type ) ) {
				$filter =  $this_pod[ 'archive_filter' ];

			} elseif ( is_home() && $current_post_type === 'post'  ) {
				$filter =  $this_pod[ 'archive_filter' ];
			} elseif ( is_tax( $current_post_type )  ) {
				$filter =  $this_pod[ 'archive_filter' ];

			}

		}
		/**
		 * Allows plugin to append/replace the_excerpt
		 *
		 * Default is false, set to true to enable.
		*/

		if ( !defined( 'PFAT_USE_ON_EXCERPT' ) ) {
			define( 'PFAT_USE_ON_EXCERPT', false);
		}

		    add_filter('the_content','ampforwp_cpt_front');

		if (  PFAT_USE_ON_EXCERPT  ) {
			add_filter( 'the_excerpt','ampforwp_cpt_front');
		}


	}


function ampforwp_cpt_current_post_type(){

		//start by getting current post or stdClass object
		global $wp_query;
		$obj = $wp_query->get_queried_object();

		//see if we are on a post type and if so, set $current_post_type to post type
		if ( isset( $obj->post_type ) ) {
			$current_post_type = $obj->post_type;

		}
		elseif ( isset( $obj->taxonomy ) ) {
			$current_post_type = $obj->taxonomy;
		}
		elseif ( isset ( $obj->name ) ) {
			$current_post_type = $obj->name;
		}
		elseif ( is_home() ) {
			$current_post_type = 'post';
		}
		else {
			$current_post_type = false;
		}

		return $current_post_type;
}

function ampforwp_current_the_pods(){
   //use the cached results
		$key = '_pods_pfat_the_pods';
		$the_pods = pods_transient_get( $key  );

		//check if we already have the results cached & use it if we can.
		if ( false === $the_pods ) {
			//get all post type pods
			$the_pods = pods_api()->load_pods( array(
					'type' => array(
						'taxonomy',
						'post_type'
					),
					'names' => true )
			);

			//cache the results
			pods_transient_set( $key, $the_pods );

		}

		return $the_pods;
}

function ampforwp_current_auto_pods(){
    	if ( function_exists( 'pods' )){

		$auto_pods = apply_filters( 'pods_pfat_auto_pods_override', null );
		if ( !is_null( $auto_pods ) ) {
			return $auto_pods;
		}

		//try to get cached results of this method
		$key = 'ampforwp_pods_pfat_auto_pods';
		$auto_pods = pods_transient_get( $key );
	
		//check if we already have the results cached & use it if we can.
		if ( $auto_pods === false  ) {
			//get possible pods
			$the_pods = ampforwp_current_the_pods();

			//start output array empty
			$auto_pods = array();

			//get pods api class
			$api = pods_api();

			//loop through each to see if auto templates is enabled
			foreach ( $the_pods as $the_pod => $the_pod_label ) {
				//get this Pods' data.
				$pod_data = $api->load_pod( array( 'name' => $the_pod ) );

				//if auto template is enabled add info about Pod to array
				if ( 1 == pods_v( 'pfat_enable', $pod_data[ 'options' ] ) ) {
					//check if pfat_single and pfat_archive are set
					$single = pods_v( 'pfat_single', $pod_data[ 'options' ], false, true );
					$archive = pods_v( 'pfat_archive', $pod_data[ 'options' ], false, true );
					$single_append = pods_v( 'pfat_append_single', $pod_data[ 'options' ], true, true );
					$archive_append = pods_v( 'pfat_append_archive', $pod_data[ 'options' ], true, true );
					$single_filter = pods_v( 'pfat_filter_single', $pod_data[ 'options' ], 'the_content', true );
					$archive_filter = pods_v( 'pfat_filter_archive', $pod_data[ 'options' ], 'the_content', true );
					$run_outside_loop = pods_v( 'pfat_run_outside_loop', $pod_data[ 'options' ], false, true );
					$type = pods_v( 'type', $pod_data, false, true );
					//check if it's a post type that has an archive
					if ( $type === 'post_type' && $the_pod !== 'post' || $the_pod !== 'page' ) {
						$has_archive = pods_v( 'has_archive', $pod_data['options'], false, true );
					}
					else {
						$has_archive = true;
					}

					if( empty( $single_filter ) ){
						$single_filter = 'the_content';
					}

					if( empty( $archive_filter  ) ){
						$archive_filter = 'the_content';
					}

					//build output array
					$auto_pods[ $the_pod ] = array(
						'name' => $the_pod,
						'label'	=> $the_pod_label,
						'single' => $single,
						'archive' => $archive,
						'single_append' => $single_append,
						'archive_append' => $archive_append,
						'has_archive'	=> $has_archive,
						'single_filter' => $single_filter,
						'archive_filter' => $archive_filter,
						'run_outside_loop' => $run_outside_loop,
						'type' => $type,
					);
				}

			} //endforeach

			//cache the results
			pods_transient_set( $key, $auto_pods );
		}

		/**
		 * Add to or change settings.
		 *
		 * Use this filter to change or add to the settings set in the back-end for this plugin. Has no effect if 'pods_pfat_auto_pods_override' filter is being used.
		 *
		 * @param array $auto_pods Array of parameters to use instead of those from settings.
		 *
		 * @return array Settings arrays for each post type.
		 *
		 * @since 2.4.5
		 */

		$auto_pods = apply_filters( 'pods_pfat_auto_pods', $auto_pods );

		return $auto_pods;

}
}

add_filter( 'ampforwp_modify_the_content','ampforwp_cpt_front');
function ampforwp_cpt_front( $content ) {

		// get the current post type
		$current_post_type = ampforwp_cpt_current_post_type();

		//now use other methods in class to build array to search in/ use
		$possible_pods = ampforwp_current_auto_pods();

		//check if $current_post_type is the key of the array of possible pods
		if ( isset( $possible_pods[ $current_post_type ] ) ) {
			//get array for the current post type
			$this_pod = $possible_pods[ $current_post_type ];

			//build Pods object for current item
			global $post;
			$pods = pods( $current_post_type, $post->ID );

			if ( $this_pod[ 'single' ] && is_singular( $current_post_type ) ) {
				//load the template
				$content = ampforwp_load_template( $this_pod[ 'single' ], $content , $pods, $this_pod[ 'single_append' ] );
			}
			//if pfat_archive was set try to use that template
			//check if we are on an archive of the post type
			elseif ( $this_pod[ 'archive' ] && is_post_type_archive( $current_post_type ) ) {
				//load the template
				$content = ampforwp_load_template( $this_pod[ 'archive' ], $content , $pods, $this_pod[ 'archive_append' ] );

			}
			//if pfat_archive was set and we're in the blog index, try to append template
			elseif ( is_home() && $this_pod[ 'archive' ] && $current_post_type === 'post'  ) {
				//append the template
				$content = ampforwp_load_template( $this_pod[ 'archive' ], $content , $pods, $this_pod[ 'archive_append' ] );

			}
			//if is taxonomy archive of the selected taxonomy
			elseif ( is_tax( $current_post_type )  ) {
				//if pfat_single was set try to use that template
				if ( $this_pod[ 'archive' ] ) {
					//append the template
					$content = ampforwp_load_template( $this_pod[ 'archive' ], $content , $pods, $this_pod[ 'archive_append' ] );
				}

			}

		}

		return $content;

	}

function ampforwp_load_template( $template_name, $content, $pods, $append = true  ) {

		//prevent infinite loops caused by this method acting on post_content
		remove_filter( 'the_content', 'ampforwp_cpt_front' );

		/**
		 * Change which template -- by name -- to be used.
		 *
		 * @since 2.5.6
		 *
		 * @param string        $template_name  The name of a Pods Template to load.
		 * @param Pods          $pods           Current Pods object.
		 * @param bool|string   $append         Whether Template will be appended (true), prepended ("prepend") or replaced (false).
		 */
		$template_name = apply_filters( 'pods_auto_template_template_name', $template_name, $pods, $append );

		$template = $pods->template( $template_name );

		//check if we have a valid template
		if ( !is_null( $template ) ) {
			//if so append it to content or replace content.

			if ( $append === 'replace' ) {
				$content = $template;
			}
			elseif ( $append === 'prepend' ) {
				$content = $template . $content;
			}
			elseif ( $append || $append === 'append' ) {
				$content = $content . $template;
			}
			else {
				$content = $template;
			}
		}

		$sanitizer = new AMP_Content( $content, array(), apply_filters( 'ampforwp_content_sanitizers', array( 'AMP_Img_Sanitizer' => array(),
                    'AMP_Style_Sanitizer' => array(),
                    'AMP_Video_Sanitizer' => array() )));
        $sanitized_content = $sanitizer->get_amp_content();

		return $sanitized_content;
	}

	//Code for rendering the tool set type view template.

add_filter('ampforwp_modify_the_content','ampforwp_tool_set_function');
function ampforwp_tool_set_function($content){
		if ( is_plugin_active( 'wp-views/wp-views.php' ) ) {
			 global $id, $post, $wp_query, $WPVDebug;
		    $template_selected = get_post_meta( $post->ID, '_views_template', true );
			$content = get_post($template_selected);
			$amp_content = do_shortcode($content->post_content);

			$sanitizer = new AMP_Content( $amp_content, array(), apply_filters( 'ampforwp_content_sanitizers', array( 'AMP_Img_Sanitizer' => array(),
		                    'AMP_Style_Sanitizer' => array(),
		                    'AMP_Video_Sanitizer' => array() )));
		        $sanitized_content = $sanitizer->get_amp_content();

				return $sanitized_content;
		}
		else{
			return $content;
		}
}

// Heroic knowledge base plugin compatibility added
 add_action('pre_amp_render_post','ampforwp_ht_kb_remove_template',24);
 function ampforwp_ht_kb_remove_template(){
 	if ( function_exists('ampforwp_remove_filters_for_class')) {
		//Remove ht-knowledge-base template
		ampforwp_remove_filters_for_class( 'the_content', 'HT_Knowledge_Base', 'ht_knowledge_base_custom_content', 10 );
		
		ampforwp_remove_filters_for_class( 'the_excerpt', 'HT_Knowledge_Base', 'ht_knowledge_base_custom_content', 10 ); 
	}
 }


//custom editors for every post type
require 'custom-amp-editor.php';

require_once dirname( __FILE__ ) . '/updater/EDD_SL_Plugin_Updater.php';

// Check for updates
function amp_cpt_plugin_updater() {

    // retrieve our license key from the DB
    //$license_key = trim( get_option( 'amp_ads_license_key' ) );
    $selectedOption = get_option('redux_builder_amp',true);
    $license_key = '';//trim( get_option( 'amp_ads_license_key' ) );
    $pluginItemName = '';
    $pluginItemStoreUrl = '';
    $pluginstatus = '';
    if( isset($selectedOption['amp-license']) && "" != $selectedOption['amp-license'] && isset($selectedOption['amp-license'][AMP_CPT_ITEM_FOLDER_NAME])){

       $pluginsDetail = $selectedOption['amp-license'][AMP_CPT_ITEM_FOLDER_NAME];
       $license_key = $pluginsDetail['license'];
       $pluginItemName = $pluginsDetail['item_name'];
       $pluginItemStoreUrl = $pluginsDetail['store_url'];
       $pluginstatus = $pluginsDetail['status'];
    }
    
    // setup the updater
    $edd_updater = new AMP_CPT_EDD_SL_Plugin_Updater( AMP_CPT_STORE_URL, __FILE__, array(
            'version'   => AMP_CPT_VERSION,                // current version number
            'license'   => $license_key,                        // license key (used get_option above to retrieve from DB)
            'license_status'=>$pluginstatus,
            'item_name' => AMP_CPT_ITEM_NAME,          // name of this plugin
            'author'    => 'Mohammed Kaludi',                   // author of this plugin
            'beta'      => false,
        )
    );
}
add_action( 'admin_init', 'amp_cpt_plugin_updater', 0 );

// Notice to enter license key once activate the plugin

$path = plugin_basename( __FILE__ );
    add_action("after_plugin_row_{$path}", function( $plugin_file, $plugin_data, $status ) {
        global $redux_builder_amp;
        if(! defined('AMP_CPT_ITEM_FOLDER_NAME')){
       $folderName = basename(__DIR__);
            define( 'AMP_CPT_ITEM_FOLDER_NAME', $folderName );
        }
       $pluginsDetail = $redux_builder_amp['amp-license'][AMP_CPT_ITEM_FOLDER_NAME];
        $pluginstatus = $pluginsDetail['status'];

        if(empty($redux_builder_amp['amp-license'][AMP_CPT_ITEM_FOLDER_NAME]['license'])){
            echo "<tr class='active'><td>&nbsp;</td><td colspan='2'><a href='".esc_url(  self_admin_url( 'admin.php?page=amp_options&tabid=opt-go-premium' )  )."'>Please enter the license key</a> to get the <strong>latest features</strong> and <strong>stable updates</strong></td></tr>";
                }elseif($pluginstatus=="valid"){
                	$update_cache = get_site_transient( 'update_plugins' );        
                    $update_cache = is_object( $update_cache ) ? $update_cache : new stdClass();
            if(isset($update_cache->response[ AMP_CPT_ITEM_FOLDER_NAME ]) 
                && empty($update_cache->response[ AMP_CPT_ITEM_FOLDER_NAME ]->download_link) 
              ){
               unset($update_cache->response[ AMP_CPT_ITEM_FOLDER_NAME ]);
            }
            set_site_transient( 'update_plugins', $update_cache );
            
        }
    }, 10, 3 );
